#ifndef DEFINES_H
 #define DEFINES_H
 #include <defines.h>
#endif

int safe_unlink(char * filename);
